@@ -30,7 +30,7 @@
 # The fact that you are presently reading this means that you have had
 # knowledge of the CeCILL-C license and that you accept its terms.
 #
-# $Id: Pdsh.py 292 2010-07-15 22:43:46Z st-cea $
+# $Id: Pdsh.py 385 2010-10-19 21:36:48Z st-cea $
 
 """
 WorkerPdsh
@@ -216,6 +216,8 @@ class WorkerPdsh(EngineClient, DistantWorker):
         # close
         self.popen.stdin.close()
         self.popen.stdout.close()
+        if self.popen.stderr:
+            self.popen.stderr.close()
 
         if timeout:
             for node in (self.nodes - self.closed_nodes):
