@@ -30,7 +30,7 @@
 # The fact that you are presently reading this means that you have had
 # knowledge of the CeCILL-C license and that you accept its terms.
 #
-# $Id: Ssh.py 334 2010-09-03 19:17:21Z st-cea $
+# $Id: Ssh.py 385 2010-10-19 21:36:48Z st-cea $
 
 """
 ClusterShell Ssh/Scp support
@@ -127,6 +127,8 @@ class Ssh(EngineClient):
 
         self.popen.stdin.close()
         self.popen.stdout.close()
+        if self.popen.stderr:
+            self.popen.stderr.close()
 
         if rc >= 0:
             self.worker._on_node_rc(self.key, rc)
