@@ -31,7 +31,7 @@
 # The fact that you are presently reading this means that you have had
 # knowledge of the CeCILL-C license and that you accept its terms.
 #
-# $Id: clush.py 352 2010-09-09 20:48:25Z st-cea $
+# $Id: clush.py 387 2010-10-20 19:00:47Z st-cea $
 
 """
 Utility program to run commands on a cluster using the ClusterShell
@@ -358,6 +358,7 @@ class RunTimer(EventHandler):
         self.cnt_last = -1
         self.tslen = len(str(self.total))
         self.wholelen = 0
+        self.started = False
 
     def ev_timer(self, timer):
         self.update()
@@ -378,8 +379,11 @@ class RunTimer(EventHandler):
                 self.tslen, self.total)
             self.wholelen = len(towrite)
             sys.stderr.write(towrite)
+            self.started = True
 
     def finalize(self, cr):
+        if not self.started:
+            return
         # display completed/total clients
         fmt = 'clush: %*d/%*d'
         if cr:
